@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -60,7 +60,6 @@
 #include <openvdb/tree/Tree.h>
 #include <openvdb/tree/LeafNode.h>
 
-#include <boost/scoped_array.hpp>
 #include <tbb/blocked_range.h>
 #include <tbb/parallel_for.h>
 #include <tbb/parallel_reduce.h>
@@ -248,10 +247,10 @@ private:
     using Range = std::pair<const IndexType*, const IndexType*>;
     using RangeDeque = std::deque<Range>;
     using RangeDequeCIter = typename RangeDeque::const_iterator;
-    using IndexArray = boost::scoped_array<IndexType>;
+    using IndexArray = std::unique_ptr<IndexType[]>;
 
     ParticleAtlas const * const mAtlas;
-    boost::scoped_array<ConstAccessorPtr> mAccessorList;
+    std::unique_ptr<ConstAccessorPtr[]> mAccessorList;
 
     // Primary index collection
     Range           mRange;
@@ -358,7 +357,7 @@ struct SplittableParticleArray
 
         if (mMaxRadius < maxRadiusLimit) return Ptr();
 
-        boost::scoped_array<bool> mask(new bool[mSize]);
+        std::unique_ptr<bool[]> mask{new bool[mSize]};
 
         tbb::parallel_for(tbb::blocked_range<size_t>(0, mSize),
             MaskParticles(*this, mask, maxRadiusLimit));
@@ -371,7 +370,7 @@ struct SplittableParticleArray
             newSize += size_t(!mask[n]);
         }
 
-        boost::scoped_array<PointIndex> newIndexMap(new PointIndex[newSize]);
+        std::unique_ptr<PointIndex[]> newIndexMap{new PointIndex[newSize]};
 
         setIndexMap(newIndexMap, mask, false);
 
@@ -390,7 +389,7 @@ private:
 
     // Masked copy constructor
     SplittableParticleArray(const SplittableParticleArray& other,
-        const boost::scoped_array<bool>& mask)
+        const std::unique_ptr<bool[]>& mask)
         : mIndexMap(), mParticleArray(&other.particleArray()), mSize(0)
     {
         for (size_t n = 0, N = other.size(); n < N; ++n) {
@@ -407,7 +406,7 @@ private:
 
     struct MaskParticles {
         MaskParticles(const SplittableParticleArray& particles,
-            const boost::scoped_array<bool>& mask, ScalarType radius)
+            const std::unique_ptr<bool[]>& mask, ScalarType radius)
             : particleArray(&particles)
             , particleMask(mask.get())
             , radiusLimit(radius)
@@ -435,8 +434,8 @@ private:
         mMaxRadius = op.maxRadius;
     }
 
-    void setIndexMap(boost::scoped_array<PointIndex>& newIndexMap,
-        const boost::scoped_array<bool>& mask, bool maskValue) const
+    void setIndexMap(std::unique_ptr<PointIndex[]>& newIndexMap,
+        const std::unique_ptr<bool[]>& mask, bool maskValue) const
     {
         if (mIndexMap.get() != nullptr) {
                 const PointIndex* indices = mIndexMap.get();
@@ -455,7 +454,7 @@ private:
 
     //////////
 
-    boost::scoped_array<PointIndex> mIndexMap;
+    std::unique_ptr<PointIndex[]> mIndexMap;
     ParticleArrayT const * const    mParticleArray;
     size_t                          mSize;
     ScalarType                      mMinRadius, mMaxRadius;
@@ -1061,6 +1060,6 @@ ParticleAtlas<PointIndexGridType>::Iterator::worldSpaceSearchAndUpdate(
 
 #endif // OPENVDB_TOOLS_PARTICLE_ATLAS_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
