@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -45,6 +45,7 @@
 
 #include "PointPartitioner.h"
 
+#include <openvdb/version.h>
 #include <openvdb/Exceptions.h>
 #include <openvdb/Grid.h>
 #include <openvdb/Types.h>
@@ -53,7 +54,6 @@
 #include <openvdb/tree/LeafNode.h>
 #include <openvdb/tree/Tree.h>
 
-#include <boost/scoped_array.hpp>
 #include <tbb/atomic.h>
 #include <tbb/blocked_range.h>
 #include <tbb/parallel_for.h>
@@ -284,7 +284,7 @@ private:
     using Range = std::pair<const ValueType*, const ValueType*>;
     using RangeDeque = std::deque<Range>;
     using RangeDequeCIter = typename RangeDeque::const_iterator;
-    using IndexArray = boost::scoped_array<ValueType>;
+    using IndexArray = std::unique_ptr<ValueType[]>;
 
     void clear();
 
@@ -431,7 +431,7 @@ struct PopulateLeafNodesOp
     using IndexT = uint32_t;
     using Partitioner = PointPartitioner<IndexT, LeafNodeT::LOG2DIM>;
 
-    PopulateLeafNodesOp(boost::scoped_array<LeafNodeT*>& leafNodes,
+    PopulateLeafNodesOp(std::unique_ptr<LeafNodeT*[]>& leafNodes,
         const Partitioner& partitioner)
         : mLeafNodes(leafNodes.get())
         , mPartitioner(&partitioner)
@@ -450,8 +450,8 @@ struct PopulateLeafNodesOp
         const IndexT voxelCount = LeafNodeT::SIZE;
 
         // allocate histogram buffers
-        boost::scoped_array<VoxelOffsetT> offsets(new VoxelOffsetT[maxPointCount]);
-        boost::scoped_array<IndexT> histogram(new IndexT[voxelCount]);
+        std::unique_ptr<VoxelOffsetT[]> offsets{new VoxelOffsetT[maxPointCount]};
+        std::unique_ptr<IndexT[]> histogram{new IndexT[voxelCount]};
 
         VoxelOffsetT const * const voxelOffsets = mPartitioner->voxelOffsets().get();
 
@@ -518,7 +518,7 @@ constructPointTree(TreeType& tree, const math::Transform& xform, const PointArra
 {
     using LeafType = typename TreeType::LeafNodeType;
 
-    boost::scoped_array<LeafType*> leafNodes;
+    std::unique_ptr<LeafType*[]> leafNodes;
     size_t leafNodeCount = 0;
 
     {
@@ -552,7 +552,7 @@ constructPointTree(TreeType& tree, const math::Transform& xform, const PointArra
 
 template<typename T>
 inline void
-dequeToArray(const std::deque<T>& d, boost::scoped_array<T>& a, size_t& size)
+dequeToArray(const std::deque<T>& d, std::unique_ptr<T[]>& a, size_t& size)
 {
     size = d.size();
     a.reset(new T[size]);
@@ -1428,7 +1428,7 @@ public:
     {
     }
 
-#ifndef OPENVDB_2_ABI_COMPATIBLE
+#if OPENVDB_ABI_VERSION_NUMBER >= 3
     PointIndexLeafNode(PartialCreate, const Coord& coords,
         const T& value = zeroVal<T>(), bool active = false)
         : BaseLeaf(PartialCreate(), coords, value, active)
@@ -1775,7 +1775,7 @@ PointIndexLeafNode<T, Log2Dim>::readBuffers(std::istream& is, const CoordBBox& b
         /// BaseLeaf::readBuffers(), the point index list will need to be regenerated.
     } else {
         // Read and discard voxel values.
-        boost::scoped_array<char> buf(new char[numBytes]);
+        std::unique_ptr<char[]> buf{new char[numBytes]};
         is.read(buf.get(), numBytes);
     }
 
@@ -1784,7 +1784,7 @@ PointIndexLeafNode<T, Log2Dim>::readBuffers(std::istream& is, const CoordBBox& b
     is.read(reinterpret_cast<char*>(&auxDataBytes), sizeof(Index64));
     if (auxDataBytes > 0) {
         // For now, read and discard any auxiliary data.
-        boost::scoped_array<char> auxData(new char[auxDataBytes]);
+        std::unique_ptr<char[]> auxData{new char[auxDataBytes]};
         is.read(auxData.get(), auxDataBytes);
     }
 }
@@ -1835,6 +1835,6 @@ struct SameLeafConfig<Dim1, openvdb::tools::PointIndexLeafNode<T2, Dim1> >
 
 #endif // OPENVDB_TOOLS_POINT_INDEX_GRID_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
